@@ -68,10 +68,8 @@ install_tinytex = function(
   )
 
   https = grepl('^https://', repository)
-  repository = sub('/+$', '', repository)
-  if ((not_ctan <- repository != 'ctan') && !grepl('/tlnet$', repository)) {
-    repository = paste0(repository, '/systems/texlive/tlnet')
-  }
+  repository = normalize_repo(repository)
+  not_ctan = repository != 'ctan'
 
   owd = setwd(tempdir()); on.exit(setwd(owd), add = TRUE)
 
@@ -85,7 +83,7 @@ install_tinytex = function(
     os,
     'unix' = {
       check_local_bin()
-      if (os_index != 2 && dir_exists('~/bin')) on.exit(message(
+      if (os_index != 3 && !dir_exists('~/bin')) on.exit(message(
         'You may have to restart your system after installing TinyTeX to make sure ',
         '~/bin appears in your PATH variable (https://github.com/yihui/tinytex/issues/16).'
       ), add = TRUE)
@@ -95,7 +93,7 @@ install_tinytex = function(
   )
 
   install = function(...) {
-    if (os_index == 0) {
+    if (need_source_install()) {
       install_tinytex_source(repository, ...)
     } else {
       install_prebuilt('TinyTeX-1', ...)
@@ -112,7 +110,7 @@ install_tinytex = function(
     if (os_index %in% c(1, 3) && https) {
       tlmgr(c('--repository', 'http://www.preining.info/tlgpg/', 'install', 'tlgpg'))
     }
-    tlmgr(c('option', 'repository', shQuote(repository)))
+    tlmgr_repo(repository)
     if (tlmgr(c('update', '--list')) != 0) {
       warning('The repository ', repository, ' does not seem to be accessible. Reverting to the default CTAN mirror.')
       tlmgr(c('option', 'repository', 'ctan'))
@@ -122,6 +120,21 @@ install_tinytex = function(
   invisible(user_dir)
 }
 
+# TinyTeX has to be installed from source for OSes that are not Linux or
+# non-x86_64 Linux machines
+need_source_install = function() {
+  os_index == 0 || (os_index == 2 && !identical(Sys.info()[['machine']], 'x86_64'))
+}
+
+# append /systems/texlive/tlnet to the repo url if necessary
+normalize_repo = function(url) {
+  # don't normalize the url if users passes I(url) or 'ctan' or NULL
+  if (is.null(url) || url == 'ctan' || inherits(url, 'AsIs')) return(url)
+  url = sub('/+$', '', url)
+  if (!grepl('/tlnet$', url)) url = paste0(url, '/systems/texlive/tlnet')
+  url
+}
+
 win_app_dir = function(..., error = TRUE) {
   d = Sys.getenv('APPDATA')
   if (d == '') {
@@ -196,7 +209,7 @@ uninstall_tinytex = function(force = FALSE, dir = tinytex_root()) {
     'Detected TeX Live at "', dir, '", but it appears to be TeX Live instead of TinyTeX. ',
     'To uninstall TeX Live, use the argument force = TRUE.'
   )
-  r_texmf('remove')
+  r_texmf('remove', .quiet = TRUE)
   tlmgr_path('remove')
   delete_texmf_user()
   unlink(dir, recursive = TRUE)
@@ -283,19 +296,12 @@ symlink_root = function(path) {
 # Generated by */TinyTeX/bin/x86_64-darwin/tlmgr on Thu Sep 17 07:13:28 2020
 is_tinytex = function() tryCatch({
   root = tinytex_root()
-  gsub('^[.]', '', tolower(basename(root))) == 'tinytex' || any(grepl(
+  root != '' && (gsub('^[.]', '', tolower(basename(root))) == 'tinytex' || any(grepl(
     '\\W[.]?TinyTeX\\W',
     readLines(file.path(root, 'texmf-dist/web2c/fmtutil.cnf'), n = 1)
-  ))
+  )))
 }, error = function(e) FALSE)
 
-in_dir = function(dir, expr) {
-  owd = setwd(dir); on.exit(setwd(owd), add = TRUE)
-  expr
-}
-
-dir_exists = function(path) file_test('-d', path)
-
 dir_rename = function(from, to) {
   # cannot rename '/foo' to '/bar' because of 'Invalid cross-device link'
   suppressWarnings(file.rename(from, to)) || dir_copy(from, to)
@@ -321,9 +327,9 @@ install_yihui_pkgs = function() {
 install_prebuilt = function(
   pkg = '', dir = '', version = '', add_path = TRUE, extra_packages = NULL, hash = FALSE, cache = NA
 ) {
-  if (os_index == 0) stop(
+  if (need_source_install()) stop(
     'There is no prebuilt version of TinyTeX for this platform: ',
-    .Platform$OS.type, '.'
+    paste(Sys.info()[c('sysname', 'machine')], collapse = ' '), '.'
   )
   dir0 = default_inst(); b = basename(dir0)
   dir1 = xfun::normalize_path(dir)  # expected installation dir
@@ -369,7 +375,7 @@ post_install_config = function(add_path, extra_packages, hash = FALSE) {
     tlmgr(c('option', 'sys_bin', '~/bin'))
   }
   if (add_path) tlmgr_path()
-  r_texmf()
+  r_texmf(.quiet = TRUE)
   tlmgr_install(setdiff(extra_packages, tl_pkgs()))
   if (hash) {
     texhash(); fmtutil(stdout = FALSE); updmap(); fc_cache()
